@@ -7,14 +7,18 @@ Listens to syncing events on daemon and displays desktop notifications.
 """
 
 from __future__ import unicode_literals
+from syncthing_gtk.tools import IS_WINDOWS
 DELAY = 5	# Display notification only after no file is downloaded for <DELAY> seconds
 
 HAS_DESKTOP_NOTIFY = False
 Notifications = None
 
 try:
-	from gi.repository import Notify
-	HAS_DESKTOP_NOTIFY = True
+	if not IS_WINDOWS:
+		import gi
+		gi.require_version('Notify', '0.7')
+		from gi.repository import Notify
+		HAS_DESKTOP_NOTIFY = True
 except ImportError:
 	pass
 
@@ -130,7 +134,17 @@ if HAS_DESKTOP_NOTIFY:
 				self.updating.add(f_path)
 		
 		def cb_syncthing_item_updated(self, daemon, folder_id, path, *a):
+			print "cb_syncthing_item_updated", folder_id, path
 			f_path = os.path.join(self.app.folders[folder_id]["norm_path"], path)
+			if ".sync-conflict" in path:
+				if os.path.exists(f_path):
+					# Updated or new conflict
+					dpath = f_path
+					if dpath.startswith(os.path.expanduser("~")):
+						dpath = "~" + dpath[len(os.path.expanduser("~")):]
+					markup = _('Conflicting file detected:\n%s' % (dpath,))
+					self.info(markup)
+					return
 			if f_path in self.updating:
 				# Check what kind of 'update' was done
 				if os.path.exists(f_path):
